<?php

namespace Drupal\rest_entity_display_menu;

/**
 * Entity display manager class.
 */
interface MenuDisplayManagerInterface {

  /**
   * Gets a normalized menu tree display from a tree and a view mode.
   *
   * @param string $menu_id
   *   The menu id.
   * @param \Drupal\Core\Menu\MenuLinkTreeElement[] $tree
   *   The tree.
   * @param string $mode
   *   The view or form mode.
   * @param string $context
   *   Either 'view' or 'form'.
   * @param string $langcode
   *   The language code of the entity to be displayed.
   *
   * @return array
   *   The normalized EntityViewDisplay or EntityFormDisplay config entity.
   */
  public function getNormalizedEntityDisplay(
    string $menu_id,
    array $tree,
    string $mode,
    string $context,
    ?string $langcode = NULL
  ): array;

  /**
   * List view and form mode with their entity display options.
   *
   * @return array
   *   The options keyed by mode (view or form).
   */
  public function getModeOptions(): array;

}
