<?php

namespace Drupal\rest_entity_display_menu;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\BundlePermissionHandlerTrait;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\rest_entity_display_menu\MenuDisplayManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a class containing permission callbacks.
 */
class RestEntityDisplayMenuPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;
  use BundlePermissionHandlerTrait;

  /**
   * Constructs a RestEntityDisplayMenuPermissions instance.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager.
   * @param \Drupal\rest_entity_display_menu\MenuDisplayManagerInterface $menuDisplayManager
   *   Menu display manager.
   */
  public function __construct(
    protected EntityTypeManagerInterface $entityTypeManager,
    protected MenuDisplayManagerInterface $menuDisplayManager
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('rest_entity_display_menu.menu_display_manager')
    );
  }

  /**
   * Returns an array of rest_entity_display_menu permissions.
   *
   * @return array
   *   The rest_entity_display_menu permissions.
   *
   * @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function permissions() {
    $perms = [];
    $menus = $this->entityTypeManager->getStorage('menu')->loadMultiple();
    foreach ($menus as $menu) {
      foreach ($this->menuDisplayManager->getModeOptions() as $mode_type => $mode) {
        foreach ($mode as $mode_id => $current_mode) {
          $perms["expose menu {$menu->id()} {$mode_type}_mode $mode_id in rest_entity_display_menu_tree_display rest resource"] = [
            'title' => $this->t('Expose menu "%menu_name" %mode_type mode "%mode" in Rest entity display menu resource.', [
              '%menu_name' => $menu->label(),
              '%mode_type' => $mode_type,
              '%mode' => (string) $current_mode,
            ])
          ];
        }
      }
    }
    return $perms;
  }

}
