<?php

namespace Drupal\rest_entity_display;

use Drupal\Core\Entity\FieldableEntityInterface;

/**
 * Entity display manager class.
 */
interface EntityDisplayManagerInterface {

  /**
   * Gets a normalized entity view/form display config entity from a fieldable entity and a view/form mode.
   *
   * @param \Drupal\Core\Entity\FieldableEntityInterface $entity
   *   The entity.
   * @param string $mode
   *   The view or form mode.
   * @param string $context
   *   Either 'view' or 'form'.
   * @param string $langcode
   *   The language code of the entity to be displayed.
   * @param \Drupal\rest_entity_display\RenderingContextInterface $rendering_context
   *   The rendering context.
   *
   * @return array
   *   The normalized EntityViewDisplay or EntityFormDisplay config entity.
   */
  public function getNormalizedEntityDisplay(
    FieldableEntityInterface $entity,
    string $mode,
    string $context,
    string $langcode = NULL,
    RenderingContextInterface $rendering_context = NULL
  ): array;

  /**
   * List view and form mode with their entity display options.
   *
   * @param string $entity_type_id
   *   The entity type identifier.
   *
   * @return array
   *   The options keyed by mode (view or form).
   */
  public function getModeOptions(string $entity_type_id): array;

}
