<?php

namespace Drupal\rest_entity_display\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Rest Entity Display configuration form.
 */
class RestEntityDisplaySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'rest_entity_display_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'rest_entity_display.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $resource_id = NULL): array {
    $config = $this->config('rest_entity_display.settings');

    $form['add_entity_type_id'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Add entity type id to elements returned in API ?'),
      '#default_value' => $config->get('add_entity_type_id'),
    ];

    $form['render_recursive_limit'] = [
      '#type' => 'number',
      '#min' => 0,
      '#title' => $this->t('Rendering recursive limit'),
      '#default_value' => $config->get('render_recursive_limit'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('rest_entity_display.settings')
      ->set('add_entity_type_id', $form_state->getValue('add_entity_type_id'))
      ->set('render_recursive_limit', $form_state->getValue('render_recursive_limit'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
