<?php

namespace Drupal\rest_entity_display\Plugin\Deriver;

use Drupal\Component\Plugin\Derivative\DeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides a resource plugin definition for form and view modes.
 *
 * @see \Drupal\rest_entity_display\Plugin\rest\resource\EntityDisplayResource
 */
class RestEntityDisplayDeriver implements DeriverInterface {

  use StringTranslationTrait;

  /**
   * List of derivative definitions.
   *
   * @var array
   */
  protected $derivatives;

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinition($derivative_id, $base_plugin_definition) {
    if (!isset($this->derivatives)) {
      $this->getDerivativeDefinitions($base_plugin_definition);
    }
    if (isset($this->derivatives[$derivative_id])) {
      return $this->derivatives[$derivative_id];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    if (!isset($this->derivatives)) {
      // Add in the default plugin configuration and the resource type.
      foreach (['form', 'view'] as $context) {
        $this->derivatives[$context] = [
          'id' => 'rest_entity_display_entity_display:' . $context,
          'context' => $context,
          'label' => $this->t('Entity %context display', ['%context' => $context]),
          'uri_paths' => [
            'canonical' => "/api/entity_{$context}_display/{entity_type_id}/{identifier}/{mode}",
          ]
        ];
        $this->derivatives[$context] += $base_plugin_definition;
      }
    }
    return $this->derivatives;
  }

}
