<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;
use Symfony\Component\Serializer\SerializerAwareTrait;

/**
 * Plugin implementation of the 'Normalized path_string' formatter.
 *
 * @FieldFormatter(
 *   id = "rest_entity_display_base_field_display_path_string",
 *   label = @Translation("Normalized String"),
 *   field_types = {
 *     "path",
 *   }
 * )
 */
#[FieldFormatter(
  id: 'rest_entity_display_base_field_display_path_string',
  label: new TranslatableMarkup('Normalized String'),
  field_types: [
    'path',
  ]
)]
class BaseFieldDisplayPathStringFormatter extends FormatterBase implements NormalizedFormatterInterface {

  use SerializerAwareTrait;
  use NormalizedFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    /** @var \Drupal\path\Plugin\Field\FieldType\PathItem $item */
    foreach ($items as $delta => $item) {
      $elements[$delta] = is_string($item->getValue()) ? $item->getValue() : $item->getValue()['alias'] ?? '';
    }

    return $elements;
  }

}
