<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceEntityFormatter;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\rest_entity_display\EntityDisplayManagerInterface;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;
use Drupal\rest_entity_display\NormalizedRenderingContextInterface;
use Drupal\rest_entity_display\NormalizedRenderingContextTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'Normalized embed entity reference' formatter.
 *
 * @FieldFormatter(
 *   id = "rest_entity_display_embed_entity_reference_formatter",
 *   label = @Translation("Normalized embed entity reference"),
 *   field_types = {
 *     "entity_reference_revisions",
 *     "entity_reference",
 *   }
 * )
 */
#[FieldFormatter(
  id: 'rest_entity_display_embed_entity_reference_formatter',
  label: new TranslatableMarkup('Normalized embed entity reference'),
  field_types: [
    'entity_reference_revisions',
    'entity_reference',
  ]
)]
class EmbedEntityReferenceFormatter extends EntityReferenceEntityFormatter implements NormalizedFormatterInterface, NormalizedRenderingContextInterface {

  use NormalizedFormatterTrait;
  use NormalizedRenderingContextTrait;

  /**
   * The entity display manager.
   *
   * @var \Drupal\rest_entity_display\EntityDisplayManagerInterface
   */
  protected EntityDisplayManagerInterface $entityDisplayManager;

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ): self {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);

    /** @var \Drupal\rest_entity_display\EntityDisplayManagerInterface $display_manager */
    $display_manager = $container->get('rest_entity_display.entity_display_manager');
    $instance->setEntityDisplayManager($display_manager);

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityDisplayManager():EntityDisplayManagerInterface {
    return $this->entityDisplayManager;
  }

  /**
   * {@inheritdoc}
   */
  public function setEntityDisplayManager(EntityDisplayManagerInterface $entityDisplayManager) {
    $this->entityDisplayManager = $entityDisplayManager;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Symfony\Component\Serializer\Exception\ExceptionInterface
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];
    $view_mode = $this->getSetting('view_mode');
    /**
     * @var \Drupal\Core\Field\EntityReferenceFieldItemList $items
     * @var \Drupal\Core\Entity\FieldableEntityInterface $entity
     *
     * @see EntityReferenceEntityFormatter::viewElements()
     */
    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $render_context = $this->getRenderingContext();
      $elements[$delta] = $this->entityDisplayManager->getNormalizedEntityDisplay($entity, $view_mode, 'view', $langcode, $render_context);
    }

    return $elements;
  }

}
