<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceFormatterBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Serializer\SerializerAwareTrait;

/**
 * Plugin implementation of the 'Normalized id entity reference' formatter.
 *
 * @FieldFormatter(
 *   id = "rest_entity_display_id_entity_reference_formatter",
 *   label = @Translation("Normalized id entity reference"),
 *   field_types = {
 *     "entity_reference_revisions",
 *     "entity_reference",
 *   }
 * )
 */
#[FieldFormatter(
  id: 'rest_entity_display_id_entity_reference_formatter',
  label: new TranslatableMarkup('Normalized id entity reference'),
  field_types: [
    'entity_reference_revisions',
    'entity_reference',
  ]
)]
class IdEntityReferenceFormatter extends EntityReferenceFormatterBase implements NormalizedFormatterInterface {

  use SerializerAwareTrait;
  use NormalizedFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ): self {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);

    /** @var \Symfony\Component\Serializer\SerializerInterface $serializer */
    $serializer = $container->get('serializer');
    $instance->setSerializer($serializer);

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      /** @var \Drupal\Core\Entity\EntityBase $entity */
      $entity = $item->entity;
      if ($entity) {
        $elements[$delta]['value'] = $entity->id();
      }
    }

    return $elements;
  }

}
