<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\LanguageFormatter as LanguageFormatterBase;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;

/**
 * Plugin implementation of the 'Normalized Language' formatter.
 *
 * @FieldFormatter(
 *   id = "rest_entity_display_language_formatter",
 *   label = @Translation("Normalized Language"),
 *   field_types = {
 *     "language",
 *   }
 * )
 */
#[FieldFormatter(
  id: 'rest_entity_display_language_formatter',
  label: new TranslatableMarkup('Normalized Language'),
  field_types: [
    'language',
  ]
)]
class LanguageFormatter extends LanguageFormatterBase implements NormalizedFormatterInterface {

  use NormalizedFormatterTrait;

  /**
   * {@inheritdoc}
   */
  protected function viewValue(FieldItemInterface $item): array {
    $languages = $this->getSetting('native_language') ?
      $this->languageManager->getNativeLanguages() :
      $this->languageManager->getLanguages(LanguageInterface::STATE_ALL);
    return [
      'value' => $item->language->getId(),
      'label' => $item->language && isset($languages[$item->language->getId()]) ? $languages[$item->language->getId()]->getName() : '',
    ];
  }

}
