<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Serializer\SerializerAwareTrait;

/**
 * Abstract formatter plugin for normalized fields.
 */
abstract class NormalizedFieldFormatter extends FormatterBase implements NormalizedFormatterInterface {

  use SerializerAwareTrait;
  use NormalizedFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ): self {
    $instance = parent::create(
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition
    );

    /** @var \Symfony\Component\Serializer\SerializerInterface $serializer */
    $serializer = $container->get('serializer');
    $instance->setSerializer($serializer);

    /** @var \Drupal\rest_entity_display\EntityViewDisplayCacheManager $cache_manager */
    $cache_manager = $container->get('rest_entity_display.cache_manager');
    $instance->setCache($cache_manager);

    return $instance;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Symfony\Component\Serializer\Exception\ExceptionInterface
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    return $this->serializer->normalize($items, 'json');
  }

}
