<?php

namespace Drupal\rest_entity_display\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\file\FileInterface;
use Drupal\file\Plugin\Field\FieldFormatter\UrlPlainFormatter as CoreUrlPlainFormatter;
use Drupal\rest_entity_display\NormalizedFormatterInterface;
use Drupal\rest_entity_display\NormalizedFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'Normalized file_url_plain' formatter.
 *
 * @FieldFormatter(
 *   id = "rest_entity_display_normalized_file_url_plain",
 *   label = @Translation("Normalized URL to file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
#[FieldFormatter(
  id: 'rest_entity_display_normalized_file_url_plain',
  label: new TranslatableMarkup('Normalized URL to file'),
  field_types: [
    'file',
  ]
)]
class UrlPlainFormatter extends CoreUrlPlainFormatter implements NormalizedFormatterInterface {

  use NormalizedFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ): self {
    $instance = parent::create(
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition
    );

    /** @var \Drupal\rest_entity_display\EntityViewDisplayCacheManager $cache_manager */
    $cache_manager = $container->get('rest_entity_display.cache_manager');
    $instance->setCache($cache_manager);

    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $file) {
      assert($file instanceof FileInterface);
      $elements[$delta] = [
        'url' => $file->createFileUrl()
      ];
      $this->getCache()->addCacheTags($file->getCacheTags());
    }

    return $elements;
  }

}
