<?php

namespace Drupal\rest_entity_display;

/**
 * Rendering context class.
 */
class RenderingContext implements RenderingContextInterface {

  /**
   * The depth limit.
   *
   * @var int
   */
  protected int $depthLimit = 0;

  /**
   * The rendered parents keys.
   *
   * @var string[]
   */
  protected array $parentsKeys = [];

  /**
   * The rendered key.
   *
   * @var string
   */
  protected string $key;

  /**
   * {@inheritdoc}
   */
  public function __construct(string $key = '', int $depthLimit = 0, array $parentsKeys = []) {
    $this->setKey($key);
    $this->setDepthLimit($depthLimit);
    $this->setParentsKeys($parentsKeys);
  }

  /**
   * {@inheritdoc}
   */
  public function getDepth(): int {
    return count($this->parentsKeys);
  }

  /**
   * {@inheritdoc}
   */
  public function getDepthLimit(): int {
    return $this->depthLimit;
  }

  /**
   * {@inheritdoc}
   */
  public function setDepthLimit(int $depthLimit): RenderingContext {
    $this->depthLimit = $depthLimit < 0 ? 0 : $depthLimit;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isDepthValid(): bool {
    return $this->getDepth() < $this->getDepthLimit();
  }

  /**
   * {@inheritdoc}
   */
  public function getParentsKeys(): array {
    return $this->parentsKeys;
  }

  /**
   * {@inheritdoc}
   */
  public function getTreeKeys(): array {
    return array_merge($this->parentsKeys, [$this->key]);
  }

  /**
   * {@inheritdoc}
   */
  public function setParentsKeys(array $parentsKeys): RenderingContext {
    $this->parentsKeys = $parentsKeys;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getKey(): string {
    return $this->key;
  }

  /**
   * {@inheritdoc}
   */
  public function setKey(string $key): RenderingContext {
    $this->key = $key;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isKeyRendered(): bool {
    return in_array($this->key, $this->parentsKeys);
  }

}
