<?php

namespace Drupal\rest_entity_display;

/**
 * Rendering context interface.
 */
interface RenderingContextInterface {

  /**
   * Construtor.
   *
   * @param string $key
   *   The rendered key.
   * @param int $depthLimit
   *   The depth limit.
   * @param array $parentsKeys
   *   The parents keys.
   */
  public function __construct(string $key = '', int $depthLimit = 0, array $parentsKeys = []);

  /**
   * Get the depth.
   *
   * @return int
   *   The depth.
   */
  public function getDepth(): int;

  /**
   * Get the depth limit.
   *
   * @return int
   *   The depth limit.
   */
  public function getDepthLimit(): int;

  /**
   * Set the depth limit.
   *
   * @param int $depthLimit
   *   The depth limit.
   *
   * @return RenderingContext
   *   The rendering context object.
   */
  public function setDepthLimit(int $depthLimit): RenderingContext;

  /**
   * Is a depth valid.
   *
   * @return bool
   *   True if depth is valid, false otherwise.
   */
  public function isDepthValid(): bool;

  /**
   * Get the parents keys.
   *
   * @return array
   *   The parents keys.
   */
  public function getParentsKeys(): array;

  /**
   * Get the tree keys.
   *
   * @return array
   *   The tree keys.
   */
  public function getTreeKeys(): array;

  /**
   * Set the parents keys.
   *
   * @param array $parentsKeys
   *   The parents keys.
   *
   * @return RenderingContext
   *   The rendering context object.
   */
  public function setParentsKeys(array $parentsKeys): RenderingContext;

  /**
   * Get the key.
   *
   * @return string
   *   The key.
   */
  public function getKey(): string;

  /**
   * Set the key.
   *
   * @param string $key
   *   The key.
   *
   * @return RenderingContext
   *   The rendering context object.
   */
  public function setKey(string $key): RenderingContext;

  /**
   * Is a parent key rendered.
   *
   * @return bool
   *   True if key already has been rendered, false otherwise.
   */
  public function isKeyRendered(): bool;

}
